## gan-mealnizer CLI

## How to run
```
gan-mealnizer run superactive 2016-09-01 2016-09-08
```

## CLI Help
```
gan-mealnizer run --help
```

```
Usage: gan-mealnizer run [OPTIONS] [USER_TYPE] [START_DATE] [END_DATE]

Arguments:
  [USER_TYPE]   active or superactive or bored  [default: active]
  [START_DATE]  Prefered format: YYYY-MM-DD  [default: 2016-09-01]
  [END_DATE]    Prefered format: YYYY-MM-DD  [default: 2016-09-08]

Options:
  --help  Show this message and exit.
```